==> kubernetes-client-6.2.0-sources.jar: io/fabric8/kubernetes/client/impl/AdmissionRegistrationAPIGroupClient.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.fabric8.kubernetes.client.impl;

import io.fabric8.kubernetes.client.AdmissionRegistrationAPIGroupDSL;
import io.fabric8.kubernetes.client.V1AdmissionRegistrationAPIGroupDSL;
import io.fabric8.kubernetes.client.V1beta1AdmissionRegistrationAPIGroupDSL;
import io.fabric8.kubernetes.client.extension.ClientAdapter;

public class AdmissionRegistrationAPIGroupClient extends ClientAdapter<AdmissionRegistrationAPIGroupClient>
    implements AdmissionRegistrationAPIGroupDSL {

  @Override
  public V1AdmissionRegistrationAPIGroupDSL v1() {
    return adapt(V1AdmissionRegistrationAPIGroupClient.class);
  }

  @Override
  public V1beta1AdmissionRegistrationAPIGroupDSL v1beta1() {
    return adapt(V1beta1AdmissionRegistrationAPIGroupClient.class);
  }

  @Override
  public AdmissionRegistrationAPIGroupClient newInstance() {
    return new AdmissionRegistrationAPIGroupClient();
  }
}

==> kubernetes-client-6.6.2-sources.jar: io/fabric8/kubernetes/client/impl/AdmissionRegistrationAPIGroupClient.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.fabric8.kubernetes.client.impl;

import io.fabric8.kubernetes.client.AdmissionRegistrationAPIGroupDSL;
import io.fabric8.kubernetes.client.V1AdmissionRegistrationAPIGroupDSL;
import io.fabric8.kubernetes.client.V1Alpha1AdmissionRegistrationAPIGroupDSL;
import io.fabric8.kubernetes.client.V1beta1AdmissionRegistrationAPIGroupDSL;
import io.fabric8.kubernetes.client.extension.ClientAdapter;

public class AdmissionRegistrationAPIGroupClient extends ClientAdapter<AdmissionRegistrationAPIGroupClient>
    implements AdmissionRegistrationAPIGroupDSL {

  @Override
  public V1AdmissionRegistrationAPIGroupDSL v1() {
    return adapt(V1AdmissionRegistrationAPIGroupClient.class);
  }

  @Override
  public V1beta1AdmissionRegistrationAPIGroupDSL v1beta1() {
    return adapt(V1beta1AdmissionRegistrationAPIGroupClient.class);
  }

  @Override
  public V1Alpha1AdmissionRegistrationAPIGroupDSL v1alpha1() {
    return adapt(V1Alpha1AdmissionRegistrationAPIGroupClient.class);
  }

  @Override
  public AdmissionRegistrationAPIGroupClient newInstance() {
    return new AdmissionRegistrationAPIGroupClient();
  }
}
